# -*- coding: utf-8 -*-
# @Created : maker
# @Time    : 1992
# @Project : chpypi
# @Software: PyCharm

proxiesKey = "wmzr5n8v"

# 代理服务器
proxyHost = "http-dyn.abuyun.com"
proxyPort = "9020"

# 代理隧道验证信息
proxyUser = "HKCK7DQ36X0862BD"
proxyPass = "BDA2D6665414DFB2"









import requests
import logging








class LOGIN:
    def __init__(self):
        ...

    def zhogntai(self,username,password):
        for _ in range(3):
            try:
                headers = {
                    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.0.0 Safari/537.36"
                }
                data = {
                    "username": username,
                    "password": password
                }
                rsp = requests.post(url='https://console.itaxs.com/api/admin/login/token', headers=headers, data=data, verify=False,timeout=20)
                jData = rsp.json()
                message = jData.get('message')
                if message == "success":
                    logging.info('----------------  登录成功，返回token  ----------------')
                    token = jData.get("data").get("access_token")
                    return token
            except Exception as e:
                logging.info('----------------  登录失败  ----------------')


# -*- coding: utf-8 -*-
# @Created : maker
# @Time    : 1992
# @Project : chpypi
# @Software: PyCharm
import getproxies
import login












class HTTPTOOLS():
    def __init__(self):
        ...

    def login_chen_hai(self):
        return login.LOGIN

    def get_proxies(self):
        return getproxies.PROXIES









#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages            #这个包没有的可以pip一下

setup(
    name = "chpypi",      #这里是pip项目发布的名称
    version = "1.1.9",  #版本号，数值大的会优先被pip
    keywords = ["pip", "chpypi"],			# 关键字
    description = "maker's private utils.",	# 描述
    long_description = "maker's private utils.",
    license = "MIT Licence",		# 许可证
    url = "https://www.itax.com",     #项目相关文件地址，一般是github项目地址即可
    author = "maker",			#作者
    author_email = "526548354@qq.com",
    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ["requests"]          #这个项目依赖的第三方库
)



import requests
from chpypi import settings


class PROXIES:

    def __init__(self):
        ...

    @classmethod
    def get_shenlong_proxies(cls):
        '''神龙代理'''
        for _ in range(3):
            try:
                rsp = requests.get(
                    url="http://api.shenlongip.com/ip?key=" + settings.proxiesKey + "&pattern=txt&count=1&protocol=2",
                    timeout=5)
                code = rsp.status_code
                r = rsp.text.strip()
                if "白名单" in r:
                    return {"code": 400, "message": r, "proxies": ""}
                elif code == 200:
                    proxies = {"https": "http://" + r,
                               "http": "http://" + r}
                    return {"code": 200, "message": "success", "proxies": proxies}
                else:
                    return {"code": 401, "message": r, "proxies": ""}
            except:
                return {"code": 500,
                        "message": 'failed to Obtain ip,try again',
                        "proxies": ""}

    @classmethod
    def get_aby_proxies(cls):
        proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
            "host": settings.proxyHost,
            "port": settings.proxyPort,
            "user": settings.proxyUser,
            "pass": settings.proxyPass,
        }
        proxies = {
            "http": proxyMeta,
            "https": proxyMeta,
        }
        return proxies


if __name__ == '__main__':
    ...
